@@ -42,11 +42,27 @@ stackMeta <- function(file,  quantity = "all", category = "image", allResolution
     if("all" %in% category) category <- unique(meta$DATA$CATEGORY)
     quantAvail <- quantity %in% meta$DATA$QUANTITY
     typAvail <- category %in% meta$DATA$CATEGORY
-    if(sum(quantAvail)  == 0) stop("None of the specifed quantities exist according to the metadata. You specified:", paste0(quantity, collapse=", "), call.=FALSE )
-    if(any(!quantAvail)) warning("The following specified quantities don't exist: ", paste0(quantity[!quantAvail], collapse=", ") ,"\nReturning available quantities:", paste0(quantity[quantAvail], collapse=", "), call.=FALSE)
-    if(sum(typAvail)  == 0) stop("None of the specifed categories exists according to the metadata. You specified:", paste0(category, collapse=", "), call.=FALSE )
-    if(any(!typAvail)) warning("The following specified categories don't exist: ", paste0(category[!typAvail], collapse=", ") ,"\nReturning available categories:", paste0(category[typAvail], collapse=", "), call.=FALSE)
+    if(sum(quantAvail)  == 0) 
+		stop("None of the specifed quantities exist according to the metadata. You specified: ", paste0(quantity, collapse=", "),
+				"\nThis is what's available:\n",
+					paste(capture.output(print(meta$DATA[,c("QUANTITY","CATEGORY")])), collapse = "\n"), call. = FALSE) 
+    if(any(!quantAvail)) 
+		warning("The following specified quantities don't exist: ", paste0(quantity[!quantAvail], collapse=", ") ,"\nReturning available quantities:", paste0(quantity[quantAvail], collapse=", "), call.=FALSE)
+    if(sum(typAvail)  == 0) 
+		stop("None of the specifed categories exists according to the metadata. You specified: ", paste0(category, collapse=", "),
+				"\nThis is what's available:\n",
+					paste(capture.output(print(meta$DATA[,c("QUANTITY","CATEGORY")])), collapse = "\n"), call. = FALSE) 
+    if(any(!typAvail))
+		warning("The following specified categories don't exist: ", paste0(category[!typAvail], collapse=", ") ,"\nReturning available categories:", paste0(category[typAvail], collapse=", "), call.=FALSE)
     
+    combi <- paste0(quantity,category) %in% paste0(meta$DATA$QUANTITY, meta$DATA$CATEGORY)
+	if(any(!combi)) {
+		if(sum(combi) < 1) stop("Both quantity and category do exist, but not in this combination. \nThis is what's available:\n",
+					paste(capture.output(print(meta$DATA[,c("QUANTITY","CATEGORY")])), collapse = "\n"), call. = FALSE) 
+        #warning("The following combination of quantity and category does not exist: ", paste0("quantity == '", quantity, "' & category == '", category)[combi],"'")
+	}
+	
+	
     ## Load layers
     path  <- if(basename(metaFile) != metaFile)  gsub(basename(metaFile), "", metaFile) else NULL
     
