@@ -86,7 +86,6 @@ superClass <- function(img, trainData, valData = NULL, responseCol = NULL,
 	# TODO: check applicability of raster:::.intersectExtent 
 	# TODO: check for empty factor levels
 	# TODO: consider splitting large polygons if there are few polygons in total
-	seeds <- as.list(sample.int(kfold*tuneLength+2))
 	if(!missing("verbose")) .initVerbose(verbose)
 	verbose <- getOption("RStoolbox.verbose")
 	## Object types
@@ -164,7 +163,7 @@ superClass <- function(img, trainData, valData = NULL, responseCol = NULL,
 	## Split into training and validation data (polygon basis)
 	if(is.null(valData) & !is.null(trainPartition)){
 		training  <- createDataPartition(trainData[[responseCol]], p = trainPartition)[[1]] ## this works for polygons as well because every polygon has only one entry in the attribnute table @data
-		if(length(training) == nrow(trainData)) stop(paste0("There are not enough polygons to split into training and validation partitions. \n  You could either ",
+		if(length(training) == nrow(trainData)) stop(paste0("There are not enough polygons/points to split into training and validation partitions. \n  You could either ",
 							"\n   * provide more (often smaller) polygons instead of few large ones (recommended)",
 							"\n   * provide pre-defined validation polygons via the valData argument",
 							"\n   * decrease trainPartition",
@@ -181,8 +180,10 @@ superClass <- function(img, trainData, valData = NULL, responseCol = NULL,
 								"\n    * run without independent validation."))
 		}
 		valData   <- trainData[-training,]
-		trainData <- trainData[training,]
-	}
+		trainData <- trainData[ training,]
+	} else {
+        training <- 1:NROW(trainData)
+    }
 	
 	
 	if(identical(trainData, valData)) stop("trainData is the same as valData")	
@@ -208,10 +209,30 @@ superClass <- function(img, trainData, valData = NULL, responseCol = NULL,
 		} else { 
 			## Check for and deal with overlapping training & validation data                 
 			dummy <- if(minDist != 0) .omniBuffer(trainData, minDist = minDist, img = img)  else trainData
-			inter <- gIntersects(valData, dummy, byid = T)
+			inter <- gIntersects(valData, dummy, byid = TRUE)
 			if(any(inter)){            
 				inter <- colnames(inter)[which(inter, arr.ind = TRUE)[,2]]
 				valData <- valData[!rownames(valData@data) %in% inter,]
+				
+				if(!nrow(valData)){
+					stop(paste0("After applying a buffer of ",minDist," pixels (minDist) no validation points remained.",
+									"\nPossible solutions:",
+									"\n * split datasets yourself, i.e. provide valData instead of trainPartition",
+									"\n * reduce minDist (may cause optimistic bias in validation!)",
+									"\n * provide more trainingPoints which are well spread across the scene"		
+									), call. = FALSE)
+				}
+				## TODO: add tests
+				if(mode == "classification" && !all(classMapping$class %in% valData[[responseCol]])){
+					stop(paste0("After applying a buffer of ",minDist," pixels (minDist) validation not all classes are represented in the validation set.",
+									"\nPossible solutions:",
+									"\n * split datasets yourself, i.e. provide valData instead of trainPartition",
+									"\n * reduce minDist (may cause optimistic bias in validation!)",
+									"\n * provide more trainingPoints which are well spread across the scene"		
+							), call. = FALSE)
+				}
+				
+				
 			}
 		}     
 	}
@@ -236,8 +257,6 @@ superClass <- function(img, trainData, valData = NULL, responseCol = NULL,
 		dataSet[[foldCol]] <- NULL
 	}
 	
-	
-	
 	## Meaningless predictors
 	uniqueVals  <- apply(dataSet, 2, function(x){length(unique(x))}) == 1
 	if(uniqueVals[1]) stop("Response (responseCol in trainData) contains only one value. Classification doesn't make sense in this case.")
@@ -251,7 +270,6 @@ superClass <- function(img, trainData, valData = NULL, responseCol = NULL,
 	.registerDoParallel()
 	indexIn <- if(polygonBasedCV) lapply(1:kfold, function(x) which(x != indexOut)) 
 	if(model == "mlc") model <- mlcCaret
-	set.seed(seeds[[1]])
 	caretModel 	<- train(response ~ ., data = dataSet, method = model, tuneLength = tuneLength, 
 			trControl = trainControl(method = "cv", number = kfold, index = indexIn, savePredictions = "final"), ...)   
 	modelFit <- getTrainPerf(caretModel)
@@ -288,14 +306,13 @@ superClass <- function(img, trainData, valData = NULL, responseCol = NULL,
 		nSamplesV <- unlist(Map("max", nSamples, 500))
 		.vMessage("Begin validation")
 		if(predict & (predType == "raw")){
-			set.seed(seeds[[kfold+2]])
-			valiSet  <- .samplePixels(valData, spatPred, responseCol = responseCol, nSamples = nSamplesV,  trainCells = dataList[[2]])[[1]]
-			colnames(valiSet) <- c("reference", "prediction")
+			valiSet  <- .samplePixels(valData, spatPred, responseCol = responseCol, nSamples = nSamplesV,  trainCells = dataList[[2]][,"cell"], withXY = TRUE)	
+            colnames(valiSet[[1]]) <- c("reference", "prediction")
+            valiSet 	<- data.frame(valiSet[[1]], valiSet[[2]])
 		} else {
-			set.seed(seeds[[kfold+2]])
-			val     <- .samplePixels(valData, img, responseCol = responseCol, nSamples = nSamplesV, trainCells = dataList[[2]])[[1]]
-			pred    <- predict(caretModel, val[,-1,drop=FALSE])
-			valiSet <- data.frame(reference = val[,1], prediction = pred)
+			val     <- .samplePixels(valData, img, responseCol = responseCol, nSamples = nSamplesV, trainCells = dataList[[2]][,"cell"], withXY = TRUE)
+			pred    <- predict(caretModel, val[[1]][,-1,drop=FALSE])
+			valiSet <- data.frame(reference = val[[1]][,1], prediction = pred, val[[2]])
 		}
 		
 		if(mode == "classification"){
@@ -312,7 +329,7 @@ superClass <- function(img, trainData, valData = NULL, responseCol = NULL,
 			valiSet$residuals <- valiSet$reference - valiSet$prediction
 			validation <-  data.frame(RMSE = .rmse(valiSet$prediction, valiSet$reference), Rsquared = cor(valiSet$prediction, valiSet$reference, use = "complete.obs")^2)   
 		}
-		validation <- list(performance = validation, validationSet = valiSet)
+		validation <- list(performance = validation, validationSamples = valiSet, validationGeometry = valData )
 	} else {
 		validation <- "No independent validation was performed!"
 	}
@@ -324,16 +341,17 @@ superClass <- function(img, trainData, valData = NULL, responseCol = NULL,
 		print(modelFit)
 		message(paste0(paste0(rep("*",20), collapse = "")," Validation summary " , paste0(rep("*",20), collapse = "")))
 		print(validation[[1]])
-	}
-	
-	out <- list(model = caretModel, modelFit = modelFit, validation = validation, map = spatPred)
-	if(exists("training")) out <- c(out, trainingPartitionIndices = training)
+	} 
+    
+    
+	out <- list(model = caretModel, modelFit = modelFit, training = list(trainingDataPartition=training), validation = validation, map = spatPred)
+
 	if(mode == "classification") out$classMapping <- classMapping 
 	structure(out, class = c("superClass", "RStoolbox"))
 }
 
 
-.samplePixels <- function(SHAPE, RASTER, responseCol, trainCells = NULL, nSamples, maxnpix = FALSE){
+.samplePixels <- function(SHAPE, RASTER, responseCol, trainCells = NULL, nSamples, maxnpix = FALSE, withXY = FALSE){
 	
 	if(inherits(SHAPE, "SpatialPolygons")){					
 		#cells <- cellFromPolygon(RASTER, SHAPE),
@@ -343,30 +361,44 @@ superClass <- function(img, trainData, valData = NULL, responseCol = NULL,
 					rc <- crop(r, extent(SHAPE[i,]) + buff)
 					rc <- rasterize(SHAPE[i,], rc, fun = "first", silent=TRUE)
 					xy <- rasterToPoints(rc)[,-3,drop=FALSE]			
-					cellFromXY(RASTER, xy)
+					if(withXY) {
+                        data.frame(cell = cellFromXY(RASTER, xy), xy)
+                    } else {
+                        data.frame(cell = cellFromXY(RASTER, xy))
+                    }
 				}, envir = environment()) 
 		
-		area  <- lapply(polyCells, length) 
+		area  <- lapply(polyCells, NROW) 
 		resp  <- SHAPE[[responseCol]]
 		uresp <- unique(resp)
 		totalarea <- vapply(uresp, function(xi) sum(unlist(area[resp == xi])), numeric(1))			
 		if(maxnpix) nSamples  <- min(totalarea)
-		dataSet   <- lapply(seq_along(polyCells), function(xi) {
+		dataSet   <- lapply(1:NROW(polyCells), function(xi) {
 					class <- resp[[xi]]
 					ns <- min(ceiling(nSamples * area[[xi]] / totalarea[which(uresp == resp[[xi]])]), area[[xi]] )
-					if(ns > 0) data.frame(response = class, cells = sample(polyCells[[xi]], ns)) else NULL
+					if(ns > 0) data.frame(response = class,  polyCells[[xi]][sample(1:NROW(polyCells[[xi]]), ns), , drop = FALSE]) else NULL
 				})	
 		dataSet <- do.call("rbind", dataSet)
-		dataSet <- cbind(dataSet, RASTER[dataSet[,"cells"]])        
+		dataSet <- cbind(dataSet, RASTER[dataSet[,"cell"]])        
 	} else {
-		dataSet <- data.frame(response = SHAPE[[responseCol]], extract(RASTER, SHAPE, cell=TRUE))
+        vals <- extract(RASTER, SHAPE, cell=TRUE)
+        colnames(vals) <- gsub("cells", "cell", colnames(vals))
+        if(withXY){		            
+            crds <- data.frame(coordinates(SHAPE))
+            colnames(crds) <- c("x","y")
+            dataSet <- data.frame(response = SHAPE[[responseCol]], vals, crds)            
+        } else {
+     		dataSet <- data.frame(response = SHAPE[[responseCol]], vals)
+        }		
+
 	}
 	
-	## Discard duplicate cells
-	dubs 	<- !duplicated(dataSet[,"cells"]) & complete.cases(dataSet) & !dataSet[,"cells"] %in% trainCells
-	dataSet <- dataSet[dubs,]
-	colnames(dataSet)[-c(1:2)] <- names(RASTER)
-	list(dataSet[,setdiff(colnames(dataSet), "cells")], cells = dataSet$cells)
+	## Discard duplicate cells, cells which have been in training data and incomplete samples
+	dubs 	<- !duplicated(dataSet[,"cell"]) & complete.cases(dataSet) & !dataSet[,"cell"] %in% trainCells
+	dataSet <- dataSet[dubs,]   
+    s <- colnames(dataSet) %in% c( "cell","x","y")
+	colnames(dataSet)[!s] <- c("response", names(RASTER))
+	list(dataSet[,!s],cells = dataSet[, s, drop=FALSE])
 }
 
 
