@@ -2,7 +2,7 @@ context("rasterCVA")
 
 r <- raster(val = 0, ncol = 2, nrow = 10)
 r1 <- r2 <- stack(r,r)
-s = 4
+s <- 4
 x <- c(0,s,s,s,0,-s,-s,-s, NA, 0)
 y <- c(s,s,0,-s,-s,-s,0,s, 0, NA)
 r2[[1]][] <- c(x, x + sign(x)*2)
